antares.apps.client.api package — Antares 0.0.2 documentation

# antares.apps.client.api package

## Submodules

## antares.apps.client.api.api_branch_list_address_view module

## antares.apps.client.api.api_branch_list_emails_view module

## antares.apps.client.api.api_branch_list_social_network_view module

## antares.apps.client.api.api_branch_list_telephone_view module

## antares.apps.client.api.api_business_clasification_view module

## antares.apps.client.api.api_client_attributes_view module

## antares.apps.client.api.api_client_id_view module

## antares.apps.client.api.api_client_relations_view module

## Module contents